pub struct Shape(pub Vec<usize>);Expand description
Newtype around a dimension vector that carries shape utilities.
Tuple Fields
0: Vec<usize>Implementations
Sourceimpl Shape
impl Shape
Sourcepub fn new(dims: impl IntoIterator<Item = usize>) -> Self
pub fn new(dims: impl IntoIterator<Item = usize>) -> Self
Construct from any iterator of usize.
Sourcepub fn reshape(
&self,
new_dims: impl IntoIterator<Item = usize>,
) -> Result<Shape>
pub fn reshape( &self, new_dims: impl IntoIterator<Item = usize>, ) -> Result<Shape>
Reshape — ensures the total numel is unchanged.
Sourcepub fn broadcast_with(&self, other: &Shape) -> Result<Shape>
pub fn broadcast_with(&self, other: &Shape) -> Result<Shape>
Compute the broadcast output shape of self and other (NumPy rules).
Sourcepub fn expand_dims(&self, axis: usize) -> Result<Shape>
pub fn expand_dims(&self, axis: usize) -> Result<Shape>
Insert a new axis of size 1 at axis (like np.expand_dims).
Sourcepub fn flat_index(&self, idx: &[usize]) -> Result<usize>
pub fn flat_index(&self, idx: &[usize]) -> Result<usize>
Contiguous byte offset for a multi-index into row-major storage.